@@ -245,8 +245,7 @@ mnreadCurve <- function(data, print_size, viewing_distance, reading_time, errors
         summarise (min_ps = min(correct_ps),
                    sum_err = sum((errors10), na.rm=T)) %>%
         mutate (RA = min_ps + sum_err*(0.01)) %>%
-        select (-min_ps, -sum_err)  ) %>%
-      filter (.drop != "NA") %>% select (-.drop)
+        select (-min_ps, -sum_err)  ) 
     
     # estimates MRS and CPS
     MRS_CPSdf <- as.data.frame(
@@ -254,8 +253,7 @@ mnreadCurve <- function(data, print_size, viewing_distance, reading_time, errors
         group_by (!!!grouping_var, .drop = TRUE) %>%
         arrange (correct_ps) %>% # sort temp_df by correct_ps in ascending order
         mutate (nb_row = n()) %>%
-        do (mansfield_algo(., .$correct_ps, .$nb_row, .$log_rs))  ) %>%
-      filter (.drop != "NA") %>% select (-.drop)
+        do (mansfield_algo(., .$correct_ps, .$nb_row, .$log_rs))  ) 
     
     if ( length(grouping_var) == 1 )  {
       p <- p + facet_wrap((grouping_var)[[1]], scales = "free")
